@@ -1,3 +1,4 @@
+from annotell.input_api.model.input.input_entry import Input
 import logging
 from typing import List, Optional
 
@@ -32,7 +33,7 @@ class InputResource(InputAPIResource):
         project: str,
         batch: Optional[str] = None,
         include_invalidated: bool = False,
-        external_ids: Optional[List[str]] = None
+        external_ids: Optional[List[str]] = None,
     ) -> List[InputModel.Input]:
         """
         Gets inputs for project, with option to filter for invalidated inputs
@@ -52,3 +53,28 @@ class InputResource(InputAPIResource):
             "externalIds": external_id_query_param
         }))
         return [InputModel.Input.from_json(js) for js in json_resp]
+
+    def add_annotation_type(self, input_uuid: str, annotation_type: str) -> None:
+        """
+        Adds annotation-type to the input, which informs the Annotell Platform
+        to produce a corresponding annotation for the annotation-type. Only
+        possible if the annotation-type is available in the corresponding batch
+        of the input (use method `get_annotation_types` to check).
+        """
+
+        self._client.post(
+            f"v1/inputs/{input_uuid}/actions/add-annotation-type/{annotation_type}",
+            discard_response=True
+        )
+
+    def get_inputs_by_uuids(self, input_uuids: List[str]) -> List[Input]:
+        """
+        Gets inputs using input uuids
+
+        :param input_uuids: A UUID to filter inputs on
+        :return List: List of Inputs
+        """
+
+        body = dict(uuids=input_uuids)
+        json_resp = self._client.post("v1/inputs/query", json=body)
+        return [Input.from_json(js) for js in json_resp]
